@@ -39,7 +39,6 @@
 #include <core/vm.h>
 #include "acpi.h"
 #include "asm.h"
-#include "acpi_dsdt.h"
 #include "beep.h"
 #include "constants.h"
 #include "io_io.h"
@@ -175,9 +174,6 @@ static struct rsdp rsdp_copy;
 static struct acpi_parser parsers[PARSERS_MAX_NUM];
 static uint parsers_num = 0;
 
-static bool pm1a_cnt_found = false;
-static ioport_t pm1a_cnt_ioaddr;
-static u64 facs_addr;
 static bool reset_reg_found = false;
 static ioport_t reset_reg_ioaddr;
 static u8 reset_value;
@@ -367,115 +363,13 @@ debug_dump (void *p, int len)
 	}
 }
 
-static void
-acpi_poweroff (void)
-{
-	u32 data, typx;
-
-	if (!pm1a_cnt_found)
-		return;
-	if (!acpi_dsdt_system_state[5][0])
-		return;
-	ACPI_DBG("acpi_poweroff\n");
-	typx = acpi_dsdt_system_state[5][1] << PM1_CNT_SLP_TYPX_SHIFT;
-	/* FIXME: how to handle pm1b_cnt? */
-	asm_inl (pm1a_cnt_ioaddr, &data);
-	data &= ~PM1_CNT_SLP_TYPX_MASK;
-	data |= typx & PM1_CNT_SLP_TYPX_MASK;
-	data |= PM1_CNT_SLP_EN_BIT;
-	asm_outl (pm1a_cnt_ioaddr, data);
-}
-
-static void
-acpi_pm1_sleep (u32 v)
-{
-	struct facs *facs;
-#ifdef ACPI_DSDT
-	bool m[6];
-	int i;
-	u8 n;
-#endif
-
-	ACPI_DBG("acpi_pm1_sleep 0x%x\n", v);
-
-#ifdef ACPI_DSDT
-	n = (v & PM1_CNT_SLP_TYPX_MASK) >> PM1_CNT_SLP_TYPX_SHIFT;
-	for (i = 0; i <= 5; i++) {
-		if (acpi_dsdt_system_state[i][0] &&
-		    acpi_dsdt_system_state[i][1] == n)
-			m[i] = true;
-		else
-			m[i] = false;
-	}
-	if (!m[2] && !m[3]) {
-		ACPI_DBG("acpi_pm1_sleep m[2] %d m[3] %d\n", m[2], m[3]);
-		return;
-	}
-#endif
-	facs = acpi_mapmem (facs_addr, sizeof *facs);
-	if (IS_STRUCT_SIZE_OK (facs->length, facs,
-			       facs->x_firmware_waking_vector))
-		facs->x_firmware_waking_vector = 0;
-	if (IS_STRUCT_SIZE_OK (facs->length, facs,
-			       facs->firmware_waking_vector))
-		facs->firmware_waking_vector = 0xFFFF0;
-	else
-		for (;;); /* FIXME: ERROR */
-	/* DEBUG */
-	/* the computer is going to sleep */
-	/* most devices are suspended */
-	/* vmm can't write anything to a screen here */
-	/* vmm can't input from/output to a keyboard here */
-	/* vmm can beep! */
-	beep_on ();
-	beep_set_freq (880);
-	usleep (500000);
-	beep_set_freq (440);
-	usleep (500000);
-	beep_set_freq (880);
-	usleep (500000);
-	beep_set_freq (440);
-	usleep (500000);
-	beep_set_freq (880);
-	usleep (500000);
-	beep_set_freq (440);
-	usleep (500000);
-	beep_set_freq (880);
-
-	acpi_poweroff ();
-}
-
-static int
-acpi_io_monitor (iotype_t type, ioport_t port, void *data)
-{
-	u32 v;
-
-	if (pm1a_cnt_found && port == pm1a_cnt_ioaddr) {
-		switch (type) {
-		case IOTYPE_OUTB:
-			v = *(u8 *)data;
-			break;
-		case IOTYPE_OUTW:
-			v = *(u16 *)data;
-			break;
-		case IOTYPE_OUTL:
-			v = *(u32 *)data;
-			break;
-		default:
-			goto def;
-		}
-		if (v & PM1_CNT_SLP_EN_BIT)
-			acpi_pm1_sleep (v);
-	}
- def:
-	return 0; /* pass */
-}
-
 static int
 acpi_reset_reg (iotype_t type, ioport_t port, void *data)
 {
 	u32 v;
 
+	ACPI_DBG("type %u port 0x%x\n", type, port);
+
 	switch (type) {
 	case IOTYPE_OUTB:
 		v = *(u8 *)data;
@@ -509,36 +403,10 @@ acpi_iohook (void)
 		return;
 	}
 
-	if (pm1a_cnt_found)
-		set_iofunc (pm1a_cnt_ioaddr, acpi_io_monitor);
-
 	if (reset_reg_found && reset_reg_ioaddr != 0x64)
 		set_iofunc(reset_reg_ioaddr, acpi_reset_reg);
 }
 
-static void
-get_pm1a_cnt_ioaddr (struct facp *q)
-{
-	if (IS_STRUCT_SIZE_OK (q->header.length, q, q->x_pm1a_cnt_blk)) {
-		if (q->x_pm1a_cnt_blk.address_space_id !=
-		    ADDRESS_SPACE_ID_IO)
-			panic ("X_PM1a_CNT_BLK is not I/O address");
-		if (q->x_pm1a_cnt_blk.address > 0xFFFF) {
-			panic ("X_PM1a_CNT_BLK > 0xFFFF");
-		}
-		pm1a_cnt_ioaddr = q->x_pm1a_cnt_blk.address;
-	} else if (IS_STRUCT_SIZE_OK (q->header.length, q, q->pm1a_cnt_blk)) {
-		if (q->pm1a_cnt_blk > 0xFFFF) {
-			panic ("pm1a_cnt_blk > 0xFFFF");
-		}
-		pm1a_cnt_ioaddr = q->pm1a_cnt_blk;
-	} else {
-		panic ("ACPI FACP is too short");
-	}
-	pm1a_cnt_found = true;
-	ACPI_DBG("PM1a control port is 0x%X\n", pm1a_cnt_ioaddr);
-}
-
 static void
 get_reset_reg_ioaddr (struct facp *facp)
 {
@@ -566,18 +434,32 @@ get_reset_reg_ioaddr (struct facp *facp)
 	ACPI_DBG("RESET_REG 0x%x value 0x%x\n", reset_reg_ioaddr, reset_value);
 }
 
+#ifdef ACPI_DSDT
 static void
-get_facs_addr (struct facp *facp)
+acpi_dsdt_parse(ulong dsdt)
 {
-	if (IS_STRUCT_SIZE_OK (facp->header.length, facp,
-			       facp->x_firmware_ctrl))
-		facs_addr = facp->x_firmware_ctrl;
-	else if (IS_STRUCT_SIZE_OK (facp->header.length, facp,
-				    facp->firmware_ctrl))
-		facs_addr = facp->firmware_ctrl;
-	else
-		panic ("ACPI FACP is too short");
+	u32 *p;
+	u8 *vaddr;
+	u32 len;
+
+	p = mapmem_hphys (dsdt, 8, 0);
+	if (p == NULL) {
+		panic("Failed to map dsdt.");
+	}
+	if (memcmp ((void *)p, "DSDT", 4))
+		panic ("DSDT broken");
+	len = p[1];
+	unmapmem (p, 8);
+	vaddr = mapmem_hphys (dsdt, len, MAPMEM_WRITE);
+	if (vaddr == NULL) {
+		panic("Failed to map dsdt.");
+	}
+
+	acpi_modify_aml(vaddr + 36, vaddr + len);
+
+	unmapmem (vaddr, len);
 }
+#endif
 
 static acpi_parser_t parse_facp;
 static void
@@ -588,9 +470,7 @@ parse_facp(void *table, u32 length)
 #ifdef ACPI_DSDT
 	acpi_dsdt_parse(facp->dsdt);
 #endif
-	get_pm1a_cnt_ioaddr(facp);
 	get_reset_reg_ioaddr(facp);
-	get_facs_addr(facp);
 	if (0)
 		debug_dump(facp, facp->header.length);
 }
