@@ -27,7 +27,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 /*
- * Copyright (c) 2010-2013 Yuichi Watanabe
+ * Copyright (c) 2010-2014 Yuichi Watanabe
  */
 
 #include <core/cpu.h>
@@ -257,5 +257,11 @@ apic_maskall(void)
 	apic_enable();
 }
 
+void
+apic_set_priority(vector_t priority)
+{
+	apic_write32(APIC_TPR_OFFSET, priority);
+}
+
 INITFUNC("global5", apic_init);
 INITFUNC("pcpu1", apic_pcpu_init);
