@@ -27,7 +27,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 /*
- * Copyright (c) 2010-2012 Yuichi Watanabe
+ * Copyright (c) 2010-2014 Yuichi Watanabe
  */
 
 #ifndef _CORE_CONSTANTS_H
@@ -81,12 +81,16 @@
 #define MSR_IA32_MTRR_PHYSMASK5		0x20b
 #define MSR_IA32_MTRR_PHYSBASE6		0x20c
 #define MSR_IA32_MTRR_PHYSMASK6		0x20d
+#define MSR_IA32_MTRR_PHYSBASE7		0x20e
+#define MSR_IA32_MTRR_PHYSMASK7		0x20f
+#define MSR_IA32_MTRR_PHYSBASE8		0x210
+#define MSR_IA32_MTRR_PHYSMASK8		0x211
+#define MSR_IA32_MTRR_PHYSBASE9		0x212
+#define MSR_IA32_MTRR_PHYSMASK9		0x213
 #define  MSR_IA32_MTRR_PHYSMASK_V_BIT		0x800
 #define  MSR_IA32_MTRR_PHYSMASK_MASK_MASK	0xfffffffffffff000
-#define MSR_IA32_MTRR_PHYSBASE7		0x20e
 #define  MSR_IA32_MTRR_PHYSBASE_TYPE_MASK	0xff
 #define  MSR_IA32_MTRR_PHYSBASE_BASE_MASK	0xfffffffffffff000
-#define MSR_IA32_MTRR_PHYSMASK7		0x20f
 #define MSR_IA32_MTRR_FIX64K_000	0x250
 #define MSR_IA32_MTRR_FIX16K_800	0x258
 #define MSR_IA32_MTRR_FIX16K_A00	0x259
@@ -102,6 +106,9 @@
 #define  MSR_IA32_MTRR_FIX_TYPE_SHIFT		8
 #define  MSR_IA32_MTRR_FIX_TYPE_NUM		8
 #define MSR_IA32_PAT			0x277
+#define  MSR_DATA_PAT_COUNT 8
+#define  MSR_PAT_FIELD(msrval, index) \
+	 ( ( (msrval) >> (8 * (index)) ) & 0xff );
 #define MSR_IA32_MTRR_DEF_TYPE		0x2ff
 #define  MSR_IA32_MTRR_DEF_TYPE_TYPE_MASK	0x0ff
 #define  MSR_IA32_MTRR_DEF_TYPE_FE_BIT		0x400
@@ -238,6 +245,7 @@
 #define VMCS_GUEST_GS_ACCESS_RIGHTS	0x481E
 #define VMCS_GUEST_LDTR_ACCESS_RIGHTS	0x4820
 #define VMCS_GUEST_TR_ACCESS_RIGHTS	0x4822
+#define VMCS_GUEST_ACCESS_RIGHTS_UNUSABLE	0x10000
 #define VMCS_GUEST_INTERRUPTIBILITY_STATE	0x4824
 #define VMCS_GUEST_ACTIVITY_STATE	0x4826
 #define VMCS_GUEST_SMBASE		0x4828
@@ -577,6 +585,7 @@
 					RFLAGS_SF_BIT | \
 					RFLAGS_DF_BIT | \
 					RFLAGS_OF_BIT
+#define RFLAGS_RESERVED_MASK		0xffffffffffc80020
 #define CR0_PE_BIT			0x1
 #define CR0_MP_BIT			0x2
 #define CR0_EM_BIT			0x4
@@ -604,6 +613,7 @@
 #define CR4_OSFXSR_BIT			0x200
 #define CR4_OSXMMEXCPT_BIT		0x400
 #define CR4_VMXE_BIT			0x2000
+#define CR4_PCIDE_BIT			0x20000
 #define CR4_OSXSAVE_BIT			0x40000
 #define CR4_SMEP_BIT			0x100000
 
