@@ -27,7 +27,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 /*
- * Copyright (c) 2010-2013 Yuichi Watanabe
+ * Copyright (c) 2010-2014 Yuichi Watanabe
  */
 
 #include <core/assert.h>
@@ -67,7 +67,7 @@ gbios_save (u32 start, u32 size)
 	return;
 }
 
-void
+vmmerr_t
 gbios_load (void)
 {
 	phys_t gphys_start;
@@ -77,7 +77,7 @@ gbios_load (void)
 		/*
 		 * VM0 boots with host BIOS.
 		 */
-		return;
+		return VMMERR_SUCCESS;
 	}
 
 	if (saved_gbios == NULL) {
@@ -87,10 +87,10 @@ gbios_load (void)
 	gphys_start = GBIOS_GPHYS_END + 1 - gbios_size;
 	start = mapmem(MAPMEM_GPHYS, gphys_start, gbios_size);
 	if (start == NULL) {
-		panic("Failed to map guest BIOS area.");
+		printf("Failed to load guest BIOS.\n");
+		return VMMERR_NOMEM;
 	}
 	memcpy(start, saved_gbios, gbios_size);
 	unmapmem(start, gbios_size);
+	return VMMERR_SUCCESS;
 }
-
-INITFUNC("setupvm2", gbios_load);
