@@ -27,7 +27,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 /*
- * Copyright (c) 2010-2013 Yuichi Watanabe
+ * Copyright (c) 2010-2014 Yuichi Watanabe
  */
 
 #include <core/assert.h>
@@ -47,6 +47,8 @@
 #include "process.h"
 #include <core/types.h>
 
+extern asmlinkage int int_callfunc (void *arg, asmlinkage void (*func)(void *arg));
+
 #ifdef __x86_64__
 static struct gatedesc64 intrdesctbl[NUM_OF_INT];
 #else
@@ -280,37 +282,17 @@ do_int (struct int_stack *s)
 		}
 	}
 
-	/*
-	 * We assume the vector of external interrupt is more than or
-	 * equal to EXT_INT_START(32). But there are exceptions. int 08
-	 * (EXCEPTION_DF) is used for IRQ0(system timer) and int 09 is
-	 * used for IRQ1(keyboard data ready).
-	 */
-	if (s->vector < EXT_INT_START &&
-	    !(s->vector == EXCEPTION_DF && s->s[0] != 0) &&
-	    !(s->vector == EXCEPTION_COPROCESSOR_SEGMENT_OVERRUN)) {
-		int_fatal(s);
-	}
-
-	extint_pend_interrupt (s->vector);
-
-	ASSERT(currentcpu->disable_interrupt > 0);
+	int_fatal(s);
 	currentcpu->disable_interrupt--;
 }
 
-void
-set_exception_handler (int vector, void *handler)
+int
+callfunc_and_getint (asmlinkage void (*func)(void *), void *arg)
 {
-	set_int_handler (vector, handler);
-}
+	int num;
 
-void
-set_int_handler (int vector, void *handler)
-{
-	u16 cs;
-
-	asm_rdcs (&cs);
-	init_intrgate (&intrdesctbl[vector], (ulong)handler, cs);
+	num = int_callfunc(arg, func);
+	return num;
 }
 
 static void
