@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010-2013 Yuichi Watanabe
+ * Copyright (c) 2010-2014 Yuichi Watanabe
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -376,7 +376,9 @@ vm_reset(void)
 	if (vm_get_id() == 0) {
 		setup_guestboot();
 	} else {
-		gbios_load();
+		if (gbios_load() != VMMERR_SUCCESS) {
+			apic_enter_wait_for_sipi_state();
+		}
 	}
 
 	call_initfunc("resetvm");
