@@ -27,7 +27,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 /*
- * Copyright (c) 2010-2012 Yuichi Watanabe
+ * Copyright (c) 2010-2013 Yuichi Watanabe
  */
 
 #ifndef __CORE_INITFUNC_H
@@ -37,16 +37,21 @@
 	__attribute__ ((__section__ (".initfunc"), aligned (1))) = { id, func }
 
 #define RM_INIT(func)			INITFUNC ("driver0", func)
-#define BUS_INIT(func)			INITFUNC ("driver1", func)
-#define DRIVER_INIT(func)		INITFUNC ("driver2", func)
+#define INTR_INIT2(func)		INITFUNC ("driver2", func)
+#define BUS_INIT(func)			INITFUNC ("driver3", func)
+#define DRIVER_INIT(func)		INITFUNC ("driver4", func)
 
-#define RM_PASSVM(func)			INITFUNC ("passvm4", func)
-#define BUS_PASSVM(func)		INITFUNC ("passvm5", func)
-#define DRIVER_PASSVM(func)		INITFUNC ("passvm6", func)
-#define BUS_START(func)			INITFUNC ("start0", func)
-#define DRIVER_START(func)		INITFUNC ("start1", func)
+#define INTR_SETUPVM1(func)		INITFUNC ("setupvm5", func)
+#define RM_SETUPVM(func)		INITFUNC ("setupvm6", func)
+#define BUS_SETUPVM(func)		INITFUNC ("setupvm7", func)
+#define DRIVER_SETUPVM(func)		INITFUNC ("setupvm8", func)
+#define DRIVER_START(func)		INITFUNC ("start4", func)
 
-#define BUS_RESETVM(func)		INITFUNC ("resetvm0", func)
+#define INTR_RESET1(func)		INITFUNC ("resetvm1", func)
+#define INTR_RESET2(func)		INITFUNC ("resetvm2", func)
+#define BUS_RESET(func)			INITFUNC ("resetvm3", func)
+#define DRIVER_RESET(func)		INITFUNC ("resetvm4", func)
+#define INTR_UNMASK(func)		INITFUNC ("resetvm5", func)
 
 #ifdef __x86_64__
 struct initfunc_data {
